@@ -85,14 +85,18 @@
 // ok
 #elif (__EMSCRIPTEN_major__ == 3) && (__EMSCRIPTEN_minor__ > 1)
 // ok
-#elif (__EMSCRIPTEN_major__ == 3) && (__EMSCRIPTEN_minor__ == 1) && (__EMSCRIPTEN_tiny__ >= 1)
+#elif (__EMSCRIPTEN_major__ == 3) && (__EMSCRIPTEN_minor__ == 1) && (__EMSCRIPTEN_tiny__ >= 51)
 // ok
 #else
-#error "Emscripten >= 3.1.1 is required."
+#error "Emscripten >= 3.1.51 is required."
 #endif
 #endif
 
 
+#elif defined(__CYGWIN__)
+#define MPT_OS_CYGWIN 1
+
+
 #elif defined(_WIN32)
 #define MPT_OS_WINDOWS 1
 #if !defined(_WIN32_WINDOWS) && !defined(WINVER)
@@ -379,6 +383,9 @@ static_assert(NTDDI_WIN11_GE == MPT_WIN_11_23H2);
 #ifndef MPT_OS_EMSCRIPTEN
 #define MPT_OS_EMSCRIPTEN 0
 #endif
+#ifndef MPT_OS_CYGWIN
+#define MPT_OS_CYGWIN 0
+#endif
 #ifndef MPT_OS_WINDOWS
 #define MPT_OS_WINDOWS 0
 #endif
